@@ -109,7 +109,7 @@ class Project extends \JTable
 		$query .= " AND o.userid != 0 AND p.state!= 2 ";
 		if ($getowner)
 		{
-			$query .=  " JOIN #__users as x ON x.id=p.owned_by_user ";
+			$query .=  ($admin ? ' LEFT' : '') . " JOIN #__users as x ON x.id=p.owned_by_user ";
 			$query .=  " LEFT JOIN #__xgroups as g ON g.gidNumber=p.owned_by_group ";
 		}
 
@@ -288,10 +288,6 @@ class Project extends \JTable
 		{
 			$query .= " AND p.setup_stage >= $setup_complete ";
 		}
-		if (isset($filters['timed']) && isset($filters['active']))
-		{
-			$query .= " GROUP BY p.id ";
-		}
 
 		if (!$filters['count'])
 		{
@@ -520,11 +516,11 @@ class Project extends \JTable
 			$query .= " AND p.owned_by_group != '$groupid' ";
 		}
 
-		$query .= $uid
+		/*$query .= $uid
 				? " AND (p.state = 1 OR (o.userid=" . $this->_db->quote($uid) . " AND o.status!=2
 					AND ((p.state = 1 AND p.setup_stage = " . $setup_complete . ")
 					OR (o.role = 1 AND p.owned_by_user=" . $this->_db->quote($uid) . ")))) "
-				: " AND p.state = 1 ";
+				: " AND p.state = 1 ";*/
 
 		// Sorting
 		if (!isset($filters['count']) or $filters['count'] == 0)
@@ -630,16 +626,20 @@ class Project extends \JTable
 			$query .= " AND p.provisioned=0";*/
 			$query  = "SELECT DISTINCT p.id
 					FROM `#__project_owners` AS po
-					INNER JOIN $this->_tbl AS p ON p.id=po.projectid
-					WHERE p.provisioned=0
+					INNER JOIN $this->_tbl AS p ON p.id=po.projectid ";
+			if ($uid)
+			{
+				$query .= " LEFT JOIN `#__project_owners` AS o ON p.id=o.projectid ";
+			}
+			$query .= "WHERE p.provisioned=0
 					AND po.status=1
 					AND po.groupid=" . $this->_db->quote($groupid);
 			if ($uid)
 			{
-				$query .= " AND po.userid=" . $this->_db->quote($uid);
+				$query .= " AND o.userid=" . $this->_db->quote($uid);
 			}
 			$query .= $active == 1
-					? " AND p.state != 2 "
+					? " AND p.state NOT IN (2, 3) "
 					: " AND p.state = 2 ";
 
 			$this->_db->setQuery($query);
